# If wants to run tests while building, specify the '--with check'
# option. For example:
# rpmbuild -bb --with check openvswitch.spec

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# run testsuite by default on x86 arches
%ifarch %{ix86} x86_64
%bcond_without check
%else
%bcond_with check
%endif
# option to run kernel datapath tests, requires building as root!
%bcond_with check_datapath_kernel

Name: openvswitch
Summary: Open vSwitch
Group: System Environment/Daemons daemon/database/utilities
URL: http://www.openvswitch.org/
Version: 2.5.0

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
# datapath/ is GPLv2 (although not built into any of the binary packages)
# python/compat is Python (although not built into any of the binary packages)
License: ASL 2.0 and LGPLv2+ and SISSL

%define snapshot .git20160727
%define rel 22%{?snapshot}

#define snapver 10346.git97bab959
%define srcname openvswitch
%define srcver %{version}%{?snapver:-%{snapver}}

%define dpdkver 2.2.0
%define dpdksver %(echo %{dpdkver} | cut -d. -f-2)
%define dpdktarget %{_arch}-native-linuxapp-gcc

Release: %{?snapver:0.%{snapver}.}%{rel}%{?dist}
Source: http://openvswitch.org/releases/%{srcname}-%{srcver}.tar.gz
Source1: ovs-snapshot.sh
Source10: http://dpdk.org/browse/dpdk/snapshot/dpdk-%{dpdkver}.tar.gz

# The DPDK is designed to optimize througput of network traffic using, among
# other techniques, carefully crafted x86 assembly instructions.  As such it
# currently (and likely never will) run on non-x86 platforms.
ExclusiveArch: x86_64

# ovs-patches
# Pass DPDK_OPTIONS from /etc/sysconfig/openvswitch
Patch1: openvswitch-2.4.0-dpdk-options.patch
# Add DPDK external library dependencies to the build
Patch2: openvswitch-2.5.0-dpdk-extra-libs.patch
# Fix ifup-ovs to delete the ports first
Patch3: openvswitch-rhel-Fix-ifup-ovs-to-delete-ports-first.patch
# Fix ifup-ovs to support DPDK Bond
Patch4: openvswitch-rhel-Add-support-for-DPDK-Bond.patch

# 2.5.0 tarball contains a tiny automake-related change which is not
# supposed to be there yet according to git. We revert it initially so that
# when the change officially comes in the branch-2.5 diff we dont trip
# over it.
Patch10: openvswitch-2.5-automake.patch
# commit 307d1d522d9ca0a4702cb2a395deef349aee02fb
# generated with: git diff v2.5.0..remotes/origin/branch-2.5 
Patch11: openvswitch-2.5-branch.patch

# OVS Backports
Patch20: 0001-dpif-Allow-adding-ukeys-for-same-flow-by-different-p.patch
Patch21: openvswitch-2.5-tcpdump.patch
Patch22: 0001-tnl-ports-fix-missing-netdev_close.patch
Patch23: openvswitch-netdev-dpdk-Use-instant-sending-instead-of-queue.patch
Patch24: openvswitch-ifnotifier-do-not-wake-up-when-there-is-no-db.patch

# Systemd Related Backports
Patch30: 0001-ovs-ctl-Remove-code-for-upgrading-from-Open-vSwitch-.patch
Patch31: 0002-ovs-ctl-Allow-selective-start-for-db-and-switch.patch
Patch32: 0003-utilities-ovs-ctl.in-Only-add_managers-with-vswitchd.patch
Patch33: 0004-utilities-ovs-ctl.in-Allow-non-monitoring-daemons.patch
Patch34: 0005-rhel-ovsdb-server.service-Rename-the-nonetwork-servi.patch
Patch35: 0006-rhel-Improved-Systemd-Integration.patch
Patch36: 0007-rhel-systemd-Delay-shutting-down-the-services.patch

# dpdk-patches
Patch100: dpdk-i40e-wformat.patch
Patch110: dpdk-eal-move-CPU-flags-check-from-constructor-to-init.patch
Patch120: dpdk-vhost-workaround-stale-vring-base.patch

BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python python-twisted-core python-zope-interface PyQt4 python-six
BuildRequires: desktop-file-utils
BuildRequires: groff graphviz
# make check dependencies
BuildRequires: procps-ng
%if %{with check_datapath_kernel}
BuildRequires: nmap-ncat
# would be useful but not available in RHEL or EPEL
#BuildRequires: pyftpdlib
%endif

# DPDK driver dependencies
BuildRequires: zlib-devel

# Virtual provide for depending on DPDK-enabled OVS
Provides: openvswitch-dpdk = %{version}-%{release}
# Migration path for openvswitch-dpdk package
Obsoletes: openvswitch-dpdk < 2.6.0
# Required by packaging policy for the bundled DPDK
Provides: bundled(dpdk) = %{dpdkver}

Requires: openssl iproute module-init-tools
#Upstream kernel commit 4f647e0a3c37b8d5086214128614a136064110c3
#Requires: kernel >= 3.15.0-0

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Obsoletes: openvswitch-controller <= 0:2.1.0-1

%description
Open vSwitch provides standard network bridging functions and
support for the OpenFlow protocol for remote per-flow control of
traffic.

%package -n python-openvswitch
Summary: Open vSwitch python bindings
License: ASL 2.0
BuildArch: noarch
Requires: python python-six

%description -n python-openvswitch
Python bindings for the Open vSwitch database

%package test
Summary: Open vSwitch testing utilities
License: ASL 2.0
BuildArch: noarch
Requires: python-openvswitch = %{version}-%{release}
Requires: python python-twisted-core python-twisted-web

%description test
Utilities that are useful to diagnose performance and connectivity
issues in Open vSwitch setup.

%package devel
Summary: Open vSwitch OpenFlow development package (library, headers)
License: ASL 2.0
Provides: openvswitch-static = %{version}-%{release}

%description devel
This provides static library, libopenswitch.a and the openvswitch header
files needed to build an external application.


%prep
%setup -q -n %{srcname}-%{srcver} -a 10
%patch1 -p1 -z .dpdk-options
%patch2 -p1 -z .dpdk-extra-libs
%patch3 -p1
%patch4 -p1
%patch10 -p1 -R
%patch11 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1

cd dpdk-%{dpdkver}
%patch100 -p1 -z .i40e-wformat
%patch110 -p1 -z .eal-move-CPU-flags
%patch120 -p1 -z .stale-vring-base
cd -

%build
%if 0%{?snapshot:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
./boot.sh
%endif

# Lets build DPDK first
cd dpdk-%{dpdkver}
function setconf()
{
    cf=%{dpdktarget}/.config
    if grep -q $1 $cf; then
        sed -i "s:^$1=.*$:$1=$2:g" $cf
    else
        echo $1=$2 >> $cf
    fi
}

# In case dpdk-devel is installed
unset RTE_SDK RTE_INCLUDE RTE_TARGET

# Avoid appending second -Wall to everything, it breaks hand-picked
# disablers like per-file -Wno-strict-aliasing
export EXTRA_CFLAGS="`echo %{optflags} | sed -e 's:-Wall::g'` -fPIC -Wno-error"

make V=1 O=%{dpdktarget} T=%{dpdktarget} %{?_smp_mflags} config

# DPDK defaults to optimizing for the builder host we need generic binaries
setconf CONFIG_RTE_MACHINE default

# Disable DPDK libraries not needed by OVS
setconf CONFIG_RTE_LIBRTE_TIMER n
setconf CONFIG_RTE_LIBRTE_CFGFILE n
setconf CONFIG_RTE_LIBRTE_JOBSTATS n
setconf CONFIG_RTE_LIBRTE_LPM n
setconf CONFIG_RTE_LIBRTE_ACL n
setconf CONFIG_RTE_LIBRTE_POWER n
setconf CONFIG_RTE_LIBRTE_METER n
setconf CONFIG_RTE_LIBRTE_SCHED n
setconf CONFIG_RTE_LIBRTE_DISTRIBUTOR n
setconf CONFIG_RTE_LIBRTE_REORDER n
setconf CONFIG_RTE_LIBRTE_PORT n
setconf CONFIG_RTE_LIBRTE_TABLE n
setconf CONFIG_RTE_LIBRTE_PIPELINE n
setconf CONFIG_RTE_LIBRTE_KNI n

# OVS expects a combined library
setconf CONFIG_RTE_BUILD_COMBINE_LIBS y

# Disable pcap for now, OVS configure doesn't grok it
setconf CONFIG_RTE_LIBRTE_PMD_PCAP n
# Disable vhost numa support for now, it segfaults
setconf CONFIG_RTE_LIBRTE_VHOST_NUMA n
# BNX2X driver is not stable
setconf CONFIG_RTE_LIBRTE_BNX2X_PMD n

# Disable kernel modules
setconf CONFIG_RTE_EAL_IGB_UIO n
setconf CONFIG_RTE_KNI_KMOD n

# Disable experimental stuff
setconf CONFIG_RTE_NEXT_ABI n
setconf CONFIG_RTE_LIBRTE_CRYPTODEV n
setconf CONFIG_RTE_LIBRTE_MBUF_OFFLOAD n

make V=1 O=%{dpdktarget} %{?_smp_mflags}

# Generate a list of supported drivers, its hard to tell otherwise.
cat << EOF > README.DPDK-PMDS
DPDK drivers included in this package:

EOF

for f in $(ls x86_64-native-linuxapp-gcc/lib/lib*_pmd_*); do
    basename ${f} | cut -c12- | cut -d. -f1 | tr [:lower:] [:upper:]
done >> README.DPDK-PMDS

cat << EOF >> README.DPDK-PMDS

For further information about the drivers, see
http://dpdk.org/doc/guides-%{dpdksver}/nics/index.html
EOF

cd -

# And now for OVS...
autoreconf -i

%configure --enable-ssl --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
           --with-dpdk=$(pwd)/dpdk-%{dpdkver}/%{dpdktarget}
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch

install -p -D -m 0644 \
        rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/openvswitch
install -p -D -m 0644 \
        rhel/usr_lib_systemd_system_openvswitch.service \
        $RPM_BUILD_ROOT%{_unitdir}/openvswitch.service
install -p -D -m 0644 \
        rhel/usr_lib_systemd_system_ovs-vswitchd.service \
        $RPM_BUILD_ROOT%{_unitdir}/ovs-vswitchd.service
install -p -D -m 0644 \
        rhel/usr_lib_systemd_system_ovsdb-server.service \
        $RPM_BUILD_ROOT%{_unitdir}/ovsdb-server.service

install -m 0755 rhel/etc_init.d_openvswitch \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/openvswitch.init

install -p -D -m 0644 rhel/etc_logrotate.d_openvswitch \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/openvswitch

install -m 0644 vswitchd/vswitch.ovsschema \
        $RPM_BUILD_ROOT/%{_datadir}/openvswitch/vswitch.ovsschema

install -d -m 0755 $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifdown-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifup-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs

install -d -m 0755 $RPM_BUILD_ROOT%{python_sitelib}
mv $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/* \
   $RPM_BUILD_ROOT%{python_sitelib}
rmdir $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/openvswitch

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db
touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/system-id.conf

# remove unpackaged files
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovs-benchmark \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-docker \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-parse-backtrace \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-testcontroller \
        $RPM_BUILD_ROOT/%{_sbindir}/ovs-vlan-bug-workaround \
        $RPM_BUILD_ROOT/%{_mandir}/man1/ovs-benchmark.1* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-testcontroller.* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-vlan-bug-workaround.8* \
        $RPM_BUILD_ROOT/%{_datadir}/openvswitch/scripts/ovs-save

# OVN not packaged for now
find $RPM_BUILD_ROOT -name "ovn-*" | xargs rm -f

%check
%if %{with check}
    if make check TESTSUITEFLAGS='%{_smp_mflags}' ||
       make check TESTSUITEFLAGS='--recheck'; then :;
    else
        cat tests/testsuite.log
        exit 1
    fi
%endif
%if %{with check_datapath_kernel}
    if make check-kernel RECHECK=yes; then :;
    else
        cat tests/system-kmod-testsuite.log
        exit 1
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?systemd_preun:1}
    %systemd_preun %{name}.service
%else
    if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
        /bin/systemctl --no-reload disable %{name}.service >/dev/null 2>&1 || :
        /bin/systemctl stop %{name}.service >/dev/null 2>&1 || :
    fi
%endif


%post
%if 0%{?systemd_post:1}
    %systemd_post %{name}.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif


%postun
%if 0%{?systemd_postun:1}
    %systemd_postun %{name}.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
%endif

%files -n python-openvswitch
%{python_sitelib}/ovs
%doc COPYING

%files test
%{_bindir}/ovs-test
%{_bindir}/ovs-vlan-test
%{_bindir}/ovs-l3ping
%{_bindir}/ovs-pcap
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_mandir}/man8/ovs-test.8*
%{_mandir}/man8/ovs-vlan-test.8*
%{_mandir}/man8/ovs-l3ping.8*
%{_mandir}/man1/ovs-pcap.1*
%{_mandir}/man8/ovs-tcpdump.8*
%{_mandir}/man1/ovs-tcpundump.1*
%{python_sitelib}/ovstest

%files devel
%{_libdir}/*.a
%{_libdir}/*.la
%{_libdir}/pkgconfig/*.pc
%{_includedir}/openvswitch/*
%{_includedir}/openflow/*

%files
%defattr(-,root,root)
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%dir %{_sysconfdir}/openvswitch
%config %ghost %{_sysconfdir}/openvswitch/conf.db
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%config(noreplace) %{_sysconfdir}/sysconfig/openvswitch
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovsdb-server.service
%{_unitdir}/ovs-vswitchd.service
%{_datadir}/openvswitch/scripts/openvswitch.init
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%{_datadir}/openvswitch/bugtool-plugins/
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/scripts/ovs-ctl
%config %{_datadir}/openvswitch/vswitch.ovsschema
%config %{_datadir}/openvswitch/vtep.ovsschema
%{_bindir}/ovs-appctl
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-dpctl-top
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_bindir}/ovs-pki
%{_bindir}/vtep-ctl
%{_sbindir}/ovs-bugtool
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%{_mandir}/man1/ovsdb-client.1*
%{_mandir}/man1/ovsdb-server.1*
%{_mandir}/man1/ovsdb-tool.1*
%{_mandir}/man5/ovs-vswitchd.conf.db.5*
%{_mandir}/man5/vtep.5*
%{_mandir}/man8/vtep-ctl.8*
%{_mandir}/man8/ovs-appctl.8*
%{_mandir}/man8/ovs-bugtool.8*
%{_mandir}/man8/ovs-ctl.8*
%{_mandir}/man8/ovs-dpctl.8*
%{_mandir}/man8/ovs-dpctl-top.8*
%{_mandir}/man8/ovs-ofctl.8*
%{_mandir}/man8/ovs-pki.8*
%{_mandir}/man8/ovs-vsctl.8*
%{_mandir}/man8/ovs-vswitchd.8*
%{_mandir}/man8/ovs-parse-backtrace.8*
%doc COPYING DESIGN.md INSTALL.SSL.md NOTICE README.md WHY-OVS.md
%doc FAQ.md NEWS INSTALL.DPDK.md rhel/README.RHEL
%doc dpdk-%{dpdkver}/README.DPDK-PMDS
/var/lib/openvswitch
/var/log/openvswitch
%ghost %attr(755,root,root) %{_rundir}/openvswitch

%changelog
* Tue Nov 22 2016 Flavio Leitner <fbl@redhat.com> 2.5.0-22.git20160727
- ifnotifier: do not wake up when there is no db connection (#1397504)

* Tue Nov 22 2016 Flavio Leitner <fbl@redhat.com> 2.5.0-21.git20160727
- Use instant sending instead of queue (#1397481)

* Mon Nov 21 2016 Flavio Leitner <fbl@redhat.com> - 2.5.0-20.git20160727
- dpdk vhost: workaround stale vring base (#1397196)

* Mon Nov 21 2016 Flavio Leitner <fbl@redhat.com> - 2.5.0-19.git20160727
- Do not restart the service after a package upgrade (#1397045)
- Fixed OVS to not require SSSE3 if DPDK is not used (#1397048)
- Applied the systemd backports (#1397049)
- Applied tnl fix (#1397050)

* Tue Oct 04 2016 Panu Matilainen <pmatilai@redhat.com> - 2.5.0-14.git20160727
- Update to post-2.5.0 snapshot with DPDK 2.2 from FD-Beta (#1381381)
- Obsolete openvswitch-dpdk < 2.6.0 to provide migration path
- Add spec option to run kernel datapath tests (#1375660)
- Backport ovs-tcpdump support (#1335560)
- Add ovs-pcap, ovs-tcpdump and ovs-tcpundump to -test package
- Add openvswitch-dpdk provide for testing and depending on dpdk-enablement
- Fix adding ukeys for same flow by different pmds (#1364898)
- Fixed ifup-ovs to support DPDK Bond (#1360426)
- Fixed ifup-ovs to delete the ports first (#1359890)
- Add README.DPDK-PMDS document listing drivers included in this package
- Eliminate debuginfo-artifacts (#1281913)

* Tue Jun 28 2016 Panu Matilainen <pmatilai@redhat.com> - 2.4.1-1.git20160628
- update to 2.4.1 + latest updates from 2.4-branch

* Tue Mar 22 2016 Panu Matilainen <pmatilai@redhat.com> - 2.4.0-2
- fix CVE-2016-2074 (#1319965)

* Thu Jul 30 2015 Flavio Leitner - 2.4.0-1
- updated to 2.4.0-1 (#1260116)

* Thu Jul 30 2015 Flavio Leitner - 2.3.2-1.git20150327
- updated to 2.3.2-git72bfa562 (#1248710)

* Mon Jun 22 2015 Flavio Leitner - 2.3.2-1
- updated to 2.3.2 (#1233862)
- fixed to own /var/run/openvswitch directory (#1200887)
- disabled testsuite on build by default

* Wed Apr 01 2015 Flavio Leitner - 2.3.1-3.git20150327
- updated to 2.3.1-git4750c96 (#1208230)
- commented out kernel requires
- added requires to procps-ng (testsuite #84)

* Mon Dec 15 2014 Flavio Leitner - 2.3.1-2.git20150113
- updated to 2.3.1-git3282e51 (#1178599)

* Mon Dec 15 2014 Flavio Leitner - 2.3.1-1
- updated to 2.3.1

* Mon Nov 10 2014 Flavio Leitner - 2.3.0-3.git20141107
- updated to 2.3.0-git39ebb203

* Fri Sep 05 2014 Flavio Leitner <fbl@redhat.com> - 2.3.0-1
- updated to 2.3.0 (#1138862)

* Wed Jul 23 2014 Flavio Leitner <fbl@redhat.com> - 2.1.2-3
- updated with git snapshot up to 3f0588b (#1122988)

* Thu Jun  5 2014 Flavio Leitner <fbl@redhat.com> - 2.1.2-1
- updated to 2.1.2
- require kernel 3.10.0-125 or newer (#1094867)
- obsoleted openvswitch-controller package
- removed ovsdbmonitor package

* Mon Apr  7 2014 Flavio Leitner <fbl@redhat.com> - 2.0.1-2
- bridge: don't bring up internal ports by default.
 (upstream commit 1839c35676b5c3a2a70e83477a6ce3d3c7d0d245)
- rhel: Add Patch Port support to initscripts
 (upstream commit d7aab66192b34473a8b12f31113ce7cf8b61b9a9)

* Thu Mar 27 2014 Flavio Leitner <fbl@redhat.com> - 2.0.1-1
- updated to 2.0.1
- create a -devel package
  (from Chris Wright <chrisw@redhat.com>)
- ovs-lib: allow non-root users to check service status
  (upstream commit 691e47554dd03dd6492e00bab5bd6d215f5cbd4f)

* Fri Jan 24 2014 Daniel Mach <dmach@redhat.com> - 2.0.0-7
- Mass rebuild 2014-01-24

* Wed Jan 15 2014 Flavio Leitner <fbl@redhat.com> - 2.0.0-6
- Enable DHCP support for internal ports
  (upstream commit 490db96efaf89c63656b192d5ca287b0908a6c77)

* Wed Jan 15 2014 Flavio Leitner <fbl@redhat.com> - 2.0.0-5
- disabled ovsdbmonitor packaging
  (upstream has removed the component)

* Wed Jan 15 2014 Flavio Leitner <fbl@redhat.com> - 2.0.0-4
- fedora package: fix systemd ordering and deps.
  (upstream commit b49c106ef00438b1c59876dad90d00e8d6e7b627)

* Wed Jan 15 2014 Flavio Leitner <fbl@redhat.com> - 2.0.0-3
- util: use gcc builtins to better check array sizes
  (upstream commit 878f1972909b33f27b32ad2ded208eb465b98a9b)

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 2.0.0-2
- Mass rebuild 2013-12-27

* Mon Oct 28 2013 Flavio Leitner <fbl@redhat.com> - 2.0.0-1
- updated to 2.0.0 (#1023184)

* Mon Oct 28 2013 Flavio Leitner <fbl@redhat.com> - 1.11.0-8
- applied upstream commit 7b75828bf5654c494a53fa57be90713c625085e2
  rhel: Option to create tunnel through ifcfg scripts.

* Mon Oct 28 2013 Flavio Leitner <fbl@redhat.com> - 1.11.0-7
- applied upstream commit 32aa46891af5e173144d672e15fec7c305f9a4f3
  rhel: Set STP of a bridge during bridge creation.

* Mon Oct 28 2013 Flavio Leitner <fbl@redhat.com> - 1.11.0-6
- applied upstream commit 5b56f96aaad4a55a26576e0610fb49bde448dabe
  rhel: Prevent duplicate ifup calls.

* Mon Oct 28 2013 Flavio Leitner <fbl@redhat.com> - 1.11.0-5
- applied upstream commit 79416011612541d103a1d396d888bb8c84eb1da4
  rhel: Return an exit value of 0 for ifup-ovs.

* Mon Oct 28 2013 Flavio Leitner <fbl@redhat.com> - 1.11.0-4
- applied upstream commit 2517bad92eec7e5625bc8b248db22fdeaa5fcde9
  Added RHEL ovs-ifup STP option handling

* Tue Oct 1 2013 Flavio Leitner <fbl@redhat.com> - 1.11.0-3
- don't use /var/lock/subsys with systemd (#1006412)

* Thu Sep 19 2013 Flavio Leitner <fbl@redhat.com> - 1.11.0-2
- ovsdbmonitor package is optional

* Thu Aug 29 2013 Thomas Graf <tgraf@redhat.com> - 1.11.0-1
- Update to 1.11.0

* Tue Aug 13 2013 Flavio Leitner <fbl@redhat.com> - 1.10.0-7
- Fixed openvswitch-nonetwork to start openvswitch.service (#996804)

* Sat Aug 03 2013 Petr Pisar <ppisar@redhat.com> - 1.10.0-6
- Perl 5.18 rebuild

* Tue Jul 23 2013 Thomas Graf <tgraf@redhat.com> - 1.10.0-5
- Typo

* Tue Jul 23 2013 Thomas Graf <tgraf@redhat.com> - 1.10.0-4
- Spec file fixes
- Maintain local copy of sysconfig.template

* Thu Jul 18 2013 Petr Pisar <ppisar@redhat.com> - 1.10.0-3
- Perl 5.18 rebuild

* Mon Jul 01 2013 Thomas Graf <tgraf@redhat.com> - 1.10.0-2
- Enable PIE (#955181)
- Provide native systemd unit files (#818754)

* Thu May 02 2013 Thomas Graf <tgraf@redhat.com> - 1.10.0-1
- Update to 1.10.0 (#958814)

* Thu Feb 28 2013 Thomas Graf <tgraf@redhat.com> - 1.9.0-1
- Update to 1.9.0 (#916537)

* Tue Feb 12 2013 Thomas Graf <tgraf@redhat.com> - 1.7.3-8
- Fix systemd service dependency loop (#818754)

* Fri Jan 25 2013 Thomas Graf <tgraf@redhat.com> - 1.7.3-7
- Auto-start openvswitch service on ifup/ifdown (#818754)
- Add OVSREQUIRES to allow defining OpenFlow interface dependencies

* Thu Jan 24 2013 Thomas Graf <tgraf@redhat.com> - 1.7.3-6
- Update to Open vSwitch 1.7.3

* Tue Nov 20 2012 Thomas Graf <tgraf@redhat.com> - 1.7.1-6
- Increase max fd limit to support 256 bridges (#873072)

* Thu Nov  1 2012 Thomas Graf <tgraf@redhat.com> - 1.7.1-5
- Don't create world writable pki/*/incomming directory (#845351)

* Thu Oct 25 2012 Thomas Graf <tgraf@redhat.com> - 1.7.1-4
- Don't add iptables accept rule for -p GRE as GRE tunneling is unsupported

* Tue Oct 16 2012 Thomas Graf <tgraf@redhat.com> - 1.7.1-3
- require systemd instead of systemd-units to use macro helpers (#850258)

* Tue Oct  9 2012 Thomas Graf <tgraf@redhat.com> - 1.7.1-2
- make ovs-vsctl timeout if daemon is not running (#858722)

* Mon Sep 10 2012 Thomas Graf <tgraf@redhat.com> - 1.7.1.-1
- Update to 1.7.1

* Fri Sep  7 2012 Thomas Graf <tgraf@redhat.com> - 1.7.0.-3
- add controller package containing ovs-controller

* Thu Aug 23 2012 Tomas Hozza <thozza@redhat.com> - 1.7.0-2
- fixed SPEC file so it comply with new systemd-rpm macros guidelines (#850258)

* Fri Aug 17 2012 Tomas Hozza <thozza@redhat.com> - 1.7.0-1
- Update to 1.7.0
- Fixed openvswitch-configure-ovskmod-var-autoconfd.patch because
  openvswitch kernel module name changed in 1.7.0
- Removed Source8: ovsdbmonitor-move-to-its-own-data-directory.patch
- Patches merged:
  - ovsdbmonitor-move-to-its-own-data-directory-automaked.patch
  - openvswitch-rhel-initscripts-resync.patch

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Mar 15 2012 Chris Wright <chrisw@redhat.com> - 1.4.0-5
- fix ovs network initscripts DHCP address acquisition (#803843)

* Tue Mar  6 2012 Chris Wright <chrisw@redhat.com> - 1.4.0-4
- make BuildRequires openssl explicit (needed on f18/rawhide now)

* Tue Mar  6 2012 Chris Wright <chrisw@redhat.com> - 1.4.0-3
- use glob to catch compressed manpages

* Thu Mar  1 2012 Chris Wright <chrisw@redhat.com> - 1.4.0-2
- Update License comment, use consitent macros as per review comments bz799171

* Wed Feb 29 2012 Chris Wright <chrisw@redhat.com> - 1.4.0-1
- Initial package for Fedora
